<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 */
if ( ! function_exists( 'tale_travel_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Tale Travel Pro 1.0.0
    */
    function tale_travel_pro_add_featured_section() {
    	$options = tale_travel_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $featured_enable = apply_filters( 'tale_travel_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'tale_travel_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        tale_travel_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'tale_travel_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Tale Travel Pro 1.0.0
    * @param array $input featured section details.
    */
    function tale_travel_pro_get_featured_section_details( $input ) {
        $options = tale_travel_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['featured_content_trip_' . $i] ) )
                        $page_ids[] = $options['featured_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['featured_content_trip_types'] ) ? $options['featured_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 3,
                    );                    
            break;

            case 'destination':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['featured_content_destination'] ) ? $options['featured_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 3,
                    );                    
            break;

            case 'activity':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['featured_content_activity'] ) ? $options['featured_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 3,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = tale_travel_pro_trim_content( 15 );
                    $page_post['author']    = tale_travel_pro_author_meta();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'tale_travel_pro_filter_featured_section_details', 'tale_travel_pro_get_featured_section_details' );


if ( ! function_exists( 'tale_travel_pro_render_featured_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Tale Travel Pro 1.0.0
   *
   */
   function tale_travel_pro_render_featured_section( $content_details = array() ) {
        $options = tale_travel_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];
        $column = ( $options['featured_subscribe_enable'] && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) ? 'col-2' : 'col-1';
        $subscription_title = ! empty( $options['featured_subscribe_title'] ) ? $options['featured_subscribe_title'] : '';
        $subscription_btn_title = ! empty( $options['featured_subscribe_btn_title'] ) ? $options['featured_subscribe_btn_title'] : esc_html__( 'Join Us', 'tale-travel-pro' );
        $i = 1;
        $count = count( $content_details );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="highlighted-posts" class="relative page-section">
            <div class="wrapper">
                <?php foreach ( $content_details as $content ) : 
                    if ( $i == 1 ) : ?>
                        <div class="main-highlighted-post <?php echo esc_attr( $column ); ?> clear">
                    <?php endif;

                    if ( $i == 2 ) : ?>
                        <div class="section-content col-2 clear">
                    <?php endif; ?>

                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <div class="featured-image">
                                <?php if ( ! empty( $content['image'] ) ) : ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                <?php endif; 

                                if ( ! in_array( $featured_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                    $enable_sale     = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                    $trip_price      = wp_travel_get_trip_price( $content['id'] );
                                    $sale_price      = wp_travel_get_trip_sale_price( $content['id'] );
                                    $trip_per        = get_post_meta( $content['id'], 'wp_travel_price_per', true );
                                    $settings        = wp_travel_get_settings();
                                    $currency_code   = ( isset( $settings['currency'] ) ) ? $settings['currency'] : '';
                                    $currency_symbol = wp_travel_get_currency_symbol( $currency_code );
                                    ?>
                                    <div class="price-meta-wrapper">
                                        <span class="trip-price">                       
                                            <span class="current-price">
                                                <?php 
                                                    echo esc_html( $currency_symbol );
                                                    echo ( true == $enable_sale && $sale_price ) ? esc_html( $sale_price ) : esc_html( $trip_price );
                                                ?>
                                            </span>
                                        </span><!-- .trip-price -->
                                    </div><!-- .price-meta-wrapper -->
                                <?php endif; ?>

                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php if ( in_array( $featured_content_type, array( 'category', 'post' ) ) ) :
                                    the_category( '', '', $content['id'] );
                                elseif ( ! in_array( $featured_content_type, array( 'category', 'page', 'post' ) ) ) :
                                    $categories = get_the_terms( $content['id'], 'travel_locations' );
                                    if ( ! empty( $categories ) ) : ?>
                                        <ul class="post-categories">
                                            <?php foreach ( $categories as $cat ) : ?>
                                                <li><a href="<?php echo esc_url( get_term_link( $cat->term_id ) ); ?>" rel="category tag"><?php echo esc_html( $cat->name ); ?></a></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    <?php endif; 
                                endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( $i > 1 ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>

                                <div class="entry-meta">
                                    <?php 
                                        tale_travel_pro_posted_on( $content['id'] ); 
                                        echo wp_kses_post( $content['author'] );
                                    ?>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </article>

                        <?php if ( 'col-2' == $column && $i == 1 ) : ?>
                            <div id="subscribe-newsletter">
                                <?php if ( ! empty( $options['featured_subscribe_image'] ) ) : ?>
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $options['featured_subscribe_image'] ); ?>">
                                    </div><!-- .featured-image -->
                                <?php endif; ?>

                                <?php 
                                    $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="' . esc_html( $subscription_title ) . '" subscribe_button="' . esc_html( $subscription_btn_title ) . '" show_subscribers_total=""]';
                                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                                ?>
                            </div><!-- #subscribe-newsletter -->
                        <?php endif; 

                    if ( $i == 1 ) : ?>
                        </div><!-- .main-highlighted-post -->
                    <?php endif; 

                    if ( $i > 1 && $i == $count ) : ?>
                        </div><!-- .section-content -->
                    <?php endif; 
                    $i++;
                endforeach; ?>
            </div><!-- .wrapper -->
        </div><!-- .highlighted-posts -->
        
    <?php }
endif;