<?php
/**
 * Popular Trips section
 *
 * This is the template for the content of popular trips section
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 */
if ( ! function_exists( 'tale_travel_pro_add_popular_trips_section' ) ) :
    /**
    * Add popular trips section
    *
    *@since Tale Travel Pro 1.0.0
    */
    function tale_travel_pro_add_popular_trips_section() {
    	$options = tale_travel_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $popular_trips_enable = apply_filters( 'tale_travel_pro_section_status', true, 'popular_trips_section_enable' );

        if ( true !== $popular_trips_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'tale_travel_pro_filter_popular_trips_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        tale_travel_pro_render_popular_trips_section( $section_details );
    }
endif;

if ( ! function_exists( 'tale_travel_pro_get_popular_trips_section_details' ) ) :
    /**
    * popular trips section details.
    *
    * @since Tale Travel Pro 1.0.0
    * @param array $input popular trips section details.
    */
    function tale_travel_pro_get_popular_trips_section_details( $input ) {
        $options = tale_travel_pro_get_theme_options();

        // Content type.
        $popular_trips_content_type  = $options['popular_trips_content_type'];
        $popular_trips_count = ! empty( $options['popular_trips_count'] ) ? $options['popular_trips_count'] : 3;
        
        $content = array();
        switch ( $popular_trips_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['popular_trips_content_category'] ) ? $options['popular_trips_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_trips_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_trips_count; $i++ ) {
                    if ( ! empty( $options['popular_trips_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_trips_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_trips_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_trips_count; $i++ ) {
                    if ( ! empty( $options['popular_trips_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_trips_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_trips_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $page_ids = array();

                for ( $i = 1; $i <= $popular_trips_count; $i++ ) {
                    if ( ! empty( $options['popular_trips_content_trip_' . $i] ) )
                        $page_ids[] = $options['popular_trips_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_trips_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_trips_content_trip_types'] ) ? $options['popular_trips_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_trips_count ),
                    );                    
            break;

            case 'destination':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_trips_content_destination'] ) ? $options['popular_trips_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_trips_count ),
                    );                    
            break;

            case 'activity':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_trips_content_activity'] ) ? $options['popular_trips_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_trips_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = tale_travel_pro_trim_content( 25 );
                    $page_post['author']    = tale_travel_pro_author_meta();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'tale_travel_pro_filter_popular_trips_section_details', 'tale_travel_pro_get_popular_trips_section_details' );


if ( ! function_exists( 'tale_travel_pro_render_popular_trips_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Tale Travel Pro 1.0.0
   *
   */
   function tale_travel_pro_render_popular_trips_section( $content_details = array() ) {
        $options = tale_travel_pro_get_theme_options();
        $popular_trips_content_type  = $options['popular_trips_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="most-viewed-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['popular_trips_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_trips_title'] ); ?></h2>
                    <?php endif;

                    if ( ! empty( $options['popular_trips_btn_title'] ) && ! empty( $options['popular_trips_btn_url'] ) ) : ?>
                        <a href="<?php echo esc_url( $options['popular_trips_btn_url'] ); ?>" class="more-link">
                            <?php 
                                echo esc_html( $options['popular_trips_btn_title'] ); 
                                echo tale_travel_pro_get_svg( array( 'icon' => 'right-thin' ) );
                            ?>
                        </a><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>
                                
                            <div class="entry-container">
                                <?php if ( ! in_array( $popular_trips_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                    $enable_sale     = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                    $trip_price      = wp_travel_get_trip_price( $content['id'] );
                                    $sale_price      = wp_travel_get_trip_sale_price( $content['id'] );
                                    $trip_per        = get_post_meta( $content['id'], 'wp_travel_price_per', true );
                                    $settings        = wp_travel_get_settings();
                                    $currency_code   = ( isset( $settings['currency'] ) ) ? $settings['currency'] : '';
                                    $currency_symbol = wp_travel_get_currency_symbol( $currency_code );
                                    ?>
                                    <div class="price-meta-wrapper">
                                        <span class="trip-price">                       
                                            <span class="current-price">
                                                <?php 
                                                    echo esc_html( $currency_symbol );
                                                    echo ( true == $enable_sale && $sale_price ) ? esc_html( $sale_price ) : esc_html( $trip_price );
                                                ?>
                                            </span>
                                        </span><!-- .trip-price -->
                                    </div><!-- .price-meta-wrapper -->
                                <?php endif;

                                if ( in_array( $popular_trips_content_type, array( 'category', 'post' ) ) ) :
                                    the_category( '', '', $content['id'] );
                                elseif ( ! in_array( $popular_trips_content_type, array( 'category', 'page', 'post' ) ) ) :
                                    $categories = get_the_terms( $content['id'], 'travel_locations' );
                                    if ( ! empty( $categories ) ) : ?>
                                        <ul class="post-categories">
                                            <?php foreach ( $categories as $cat ) : ?>
                                                <li><a href="<?php echo esc_url( get_term_link( $cat->term_id ) ); ?>" rel="category tag"><?php echo esc_html( $cat->name ); ?></a></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    <?php endif; 
                                endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <div class="entry-meta">
                                    <?php 
                                        tale_travel_pro_posted_on( $content['id'] ); 
                                        echo wp_kses_post( $content['author'] );
                                    ?>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->

                <?php if ( ! empty( $options['popular_trips_btn_title'] ) && ! empty( $options['popular_trips_btn_url'] ) ) : ?>
                    <a href="<?php echo esc_url( $options['popular_trips_btn_url'] ); ?>" class="more-link">
                        <?php 
                            echo esc_html( $options['popular_trips_btn_title'] ); 
                            echo tale_travel_pro_get_svg( array( 'icon' => 'right-thin' ) );
                        ?>
                    </a><!-- .more-link -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #most-viewed-posts -->

    <?php }
endif;